import os

from evote.settings import *  # noqa


DEBUG = False
TEMPLATE_DEBUG = True
COMPRESS_OFFLINE = True

SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')

ALLOWED_HOSTS = [os.environ.get('SN_EVOTE')]


# Django Site identification
SITE_ID = 4

SECRET_KEY = os.environ.get('SECRET_KEY')

MIDDLEWARE += (  # noqa
    'django.middleware.gzip.GZipMiddleware',
)

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',
        'NAME': os.environ.get('MYSQL_DATABASE'),
        'USER': os.environ.get('MYSQL_USER'),
        'PASSWORD': os.environ.get('MYSQL_PASSWORD'),
        'HOST': os.environ.get('MYSQL_HOST'),
        'PORT': '',
        'OPTIONS': {
            'init_command': 'SET storage_engine=INNODB'
        },
    }
}

CACHES = {
    "default": {
        "BACKEND": "django_redis.cache.RedisCache",
        "LOCATION": os.environ.get('REDIS_URL'),
        "KEY_PREFIX": "evote",
        "OPTIONS": {
            "CLIENT_CLASS": "django_redis.client.DefaultClient",
        }
    }
}

# Define the Queue Settings

CELERY_BROKER_URL = os.environ.get('BROKER_URL')


# sorl thumbnail settings

THUMBNAIL_REDIS_URL = os.environ.get('REDIS_URL')
THUMBNAIL_KVSTORE = "sorl.thumbnail.kvstores.redis_kvstore.KVStore"
THUMBNAIL_DUMMY = True


# Logging
# Inherited from main settings
EVOTELOG_MAIL_LIST = [('Dev', 'dev-errors@eurotux.com'), ] # noqa

# WS UM Members
MEMBERS_SERVICE_CONFIG = {
    'debug': True,
    'url': '',
    'login': '',
    'password': ''
}

# WS UM SMS Notifications
SMS_SERVICE_CONFIG = {
    'debug': True,
    'url': '',
    'login': '',
    'password': ''
}


# evote services endpoints

EVOTE_SERVICES_ENDPOINTS = {
    'anonymizer': 'https://{}/api/v1/'.format(os.environ.get("SN_EVOTE_AS")),
    'counter': 'https://{}/api/v1/'.format(os.environ.get("SN_EVOTE_CS"))
}


# Base log configs
# LOGGING
EVOTELOG_DIR = os.path.join(PROJECT_DIR, '../logs/') # noqa
EVOTELOG_MAIL_LIST = ADMINS # noqa

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'verbose': {
            'format': '[%(asctime)s] - (%(levelname)s) %(pathname)s\
                    at line: %(lineno)d - %(message)s'
        },
        'simple': {
            'format': '[%(asctime)s] - %(levelname)s - %(message)s'
        },
    },
    'handlers': {
        'mail_admins': {
            'level': 'ERROR',
            'class': 'evotelogs.loggers.AdminEmailHandler',
            'include_html': True
        },
        # Project specific handlers
        'mail_evote': {
            'level': 'ERROR',
            'class': 'evotelogs.loggers.LogsEmailHandler',
            'include_html': True
        },
        'file_handler': {
            'level': 'WARNING',
            'class': 'logging.handlers.RotatingFileHandler',
            'filename': os.path.join(EVOTELOG_DIR, 'evote.log'),
            'maxBytes': '16777216',
            'formatter': 'verbose',
        },
        'critical_handler': {
            'level': 'CRITICAL',
            'class': 'logging.FileHandler',
            'filename': os.path.join(EVOTELOG_DIR, 'critical.log'),
            'formatter': 'verbose',
        },
        'syslog_handler': {
            'level': 'WARNING',
            'class': 'logging.handlers.SysLogHandler',
            'address': '/dev/log',
            'formatter': 'verbose',
        },
    },
    'loggers': {
        'evote.logger': {
            'handlers': [
                'mail_evote',
                'file_handler',
                'critical_handler',
                'syslog_handler'
            ],
            'level': 'WARNING',
            'propagate': False,
        },
        'django.request': {
            'handlers': ['mail_admins'],
            'level': 'ERROR',
            'propagate': False,
        },
    },
}
