import os

from evote.settings import *  # noqa
from django.core.urlresolvers import reverse_lazy

import mimetypes

mimetypes.add_type("image/svg+xml", ".svg", True)
mimetypes.add_type("image/svg+xml", ".svgz", True)


DEBUG = True
TEMPLATE_DEBUG = True
THUMBNAIL_DEBUG = True


# debug toolbar settings
def show_toolbar(request):
    return True


DEBUG_TOOLBAR_PATCH_SETTINGS = False
INSTALLED_APPS += (  # noqa
    'debug_toolbar',
)
MIDDLEWARE += [  # noqa
    'debug_toolbar.middleware.DebugToolbarMiddleware',
]
DEBUG_TOOLBAR_CONFIG = {
    "SHOW_TOOLBAR_CALLBACK": show_toolbar,
}


# database settings

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',
        'NAME': os.environ.get('MYSQL_DATABASE'),
        'USER': os.environ.get('MYSQL_USER'),
        'PASSWORD': os.environ.get('MYSQL_PASSWORD'),
        'HOST': 'db',
        'PORT': '3306'
    }
}


# caching settings

CACHES = {
    "default": {
        "BACKEND": "django_redis.cache.RedisCache",
        "LOCATION": os.environ.get('REDIS_PORT'),
        "OPTIONS": {
            "CLIENT_CLASS": "django_redis.client.DefaultClient",
        }
    }
}

LOGIN_URL = reverse_lazy("voters:login")
LOGOUT_URL = reverse_lazy("voters:logout")

# celery settings

CELERY_BROKER_URL = 'amqp://{}:{}@rabbitmq//'.format(
    os.environ.get('RABBITMQ_DEFAULT_USER'),
    os.environ.get('RABBITMQ_DEFAULT_PASS'))


# sorl thumbnail settings

THUMBNAIL_REDIS_URL = os.environ.get('REDIS_PORT')
THUMBNAIL_KVSTORE = "sorl.thumbnail.kvstores.redis_kvstore.KVStore"
THUMBNAIL_DUMMY = True
THUMBNAIL_DEBUG = True

# Celery email backend
CELERY_EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'

# Email settings
DEFAULT_FROM_EMAIL = 'dev@eurotux.com'
EVOTE_MAILING_SUBJECT_DEFAULT = 'Evote'

# evote services endpoints
EVOTE_SERVICES_ENDPOINTS = {
    'anonymizer': 'http://anonymizerservice/api/v1/',
    'counter': 'http://counterservice/api/v1/'
}

# Django Site identification
SITE_ID = 1

# WS UM Members
MEMBERS_SERVICE_CONFIG = {
    'debug': True,
    'url': '',
    'login': '',
    'password': ''
}

# WS UM SMS Notifications
SMS_SERVICE_CONFIG = {
    'debug': True,
    'url': '',
    'login': '',
    'password': ''
}

# LOGGING
EVOTELOG_DIR = os.path.join(PROJECT_DIR, '../data/') # noqa
EVOTELOG_MAIL_LIST = ADMINS # noqa

# Specific Docker logging
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'verbose': {
            'format': '[%(asctime)s] - (%(levelname)s) %(pathname)s\
                    at line: %(lineno)d - %(message)s'
        },
        'simple': {
            'format': '[%(asctime)s] - %(levelname)s - %(message)s'
        },
    },
    'handlers': {
        'mail_admins': {
            'level': 'ERROR',
            'class': 'evotelogs.loggers.AdminEmailHandler',
            'include_html': True
        },
        # Project specific handlers
        'mail_evote': {
            'level': 'ERROR',
            'class': 'evotelogs.loggers.LogsEmailHandler',
            'include_html': True
        },
        'file_handler': {
            'level': 'WARNING',
            'class': 'logging.handlers.RotatingFileHandler',
            'filename': os.path.join(EVOTELOG_DIR, 'evote.log'),
            'maxBytes': '16777216',
            'formatter': 'verbose',
        },
        'critical_handler': {
            'level': 'CRITICAL',
            'class': 'logging.FileHandler',
            'filename': os.path.join(EVOTELOG_DIR, 'critical.log'),
            'formatter': 'verbose',
        },
    },
    'loggers': {
        'evote.logger': {
            'handlers': [
                'mail_evote',
                'file_handler',
                'critical_handler',
            ],
            'level': 'WARNING',
            'propagate': False,
        },
        'django.request': {
            'handlers': ['mail_admins'],
            'level': 'ERROR',
            'propagate': False,
        },
    },
}
